###################################
# Load the Assemblies 
###################################

[void][System.Reflection.Assembly]::LoadWithPartialName('PresentationCore')
[void][System.Reflection.Assembly]::LoadWithPartialName('PresentationFramework')
[void][System.Reflection.Assembly]::LoadWithPartialName('WindowsBase')
[void][System.Reflection.Assembly]::LoadWithPartialName('system.windows.forms')


##############################################################
# Define the Functions 
##############################################################

function Hosts_List($vc, $user, $pass)
{
    Add-PSSnapin VMware.VimAutomation.Core
    Connect-VIserver -Server $vc -User $user -Password $pass | Out-Null
    Get-VMHost | Out-GridView
}

##############################################################
# Define the XML object and store the XAML code into it 
##############################################################

[xml]$xamlWindow = @'
<Window Name="MainForm"
        xmlns="http://schemas.microsoft.com/winfx/2006/xaml/presentation"
        xmlns:x="http://schemas.microsoft.com/winfx/2006/xaml"
        xmlns:local="clr-namespace:TextBox_WPF"
        Title="vCenter Information" Height="350" Width="525" WindowStartupLocation="CenterScreen" ResizeMode="CanResizeWithGrip" WindowStyle="ThreeDBorderWindow">
    <Grid>
        <Label Name="label" Content="Please enter vCenter Server Name" Margin="43.336,20.814,108.143,0" VerticalAlignment="Top" FontWeight="Bold"/>
        <Label Name="label1" Content="Please enter User Name and Password" Margin="43.336,117.876,108.143,0" FontWeight="Bold" VerticalAlignment="Top"/>
        <Label Name="label2" Content="vCenter" HorizontalAlignment="Left" Margin="49.551,67.194,0,0" VerticalAlignment="Top" Width="97.283"/>
        <Label Name="label3" Content="User Name" HorizontalAlignment="Left" Margin="49.551,0,0,129.24" Width="97.283" VerticalAlignment="Bottom"/>
        <Label Name="label4" Content="Password" HorizontalAlignment="Left" Margin="50,0,0,75" VerticalAlignment="Bottom" Width="97"/>
        <TextBox Name="textBox" Height="23" Margin="198.255,67.194,29.005,0" TextWrapping="Wrap" VerticalAlignment="Top"/>
        <TextBox Name="textBox1" Height="23" Margin="198.255,0,29.005,129.254" TextWrapping="Wrap" VerticalAlignment="Bottom"/>
        <PasswordBox Name="passwordBox" HorizontalAlignment="Left" Margin="198,213,0,0" VerticalAlignment="Top" Width="276" Height="23"/>
        <Button Name="button" Content="OK" HorizontalAlignment="Left" Margin="104.06,0,0,29.113" VerticalAlignment="Bottom" Width="75" FontWeight="Bold"/>
        <Button Name="button1" Content="CANCEL" HorizontalAlignment="Right" Margin="0,0,90.263,29.113" VerticalAlignment="Bottom" Width="75" FontWeight="Bold"/>
    </Grid>
</Window>
'@

####################################
# Read the XAML information and 
####################################

$xamlReader = New-Object System.Xml.XmlNodeReader $xamlWindow

try{
    $MainForm = [Windows.Markup.XamlReader]::Load( $xamlReader )
}catch{
    Write-Host "Unable to load Windows.Markup.XamlReader. Some problem is there. Please check the XAML code entered."
    exit
}

#===========================================================================
# Store Form Objects In PowerShell
#===========================================================================

$xamlWindow.SelectNodes("//*[@Name]") | %{Set-Variable -Name ($_.Name) -Value $MainForm.FindName($_.Name)}

# Defining on Click events for the buttons

$button.add_Click({Hosts_List -vc $textBox.Text -user $textBox1.Text -pass $passwordBox.Password })

$button1.add_Click({Disconnect-VIServer $textBox.Text -Confirm:$False; $MainForm.Close()})

#===========================================================================
# Shows the form
#===========================================================================
$MainForm.ShowDialog() | out-null