﻿# Provided below is an example of a function which utilizes Dynamic Parameters


Function Create-VM {
    [CmdletBinding()]
    param(
        [Parameter(
            Mandatory=$true,
            Position=1,
            HelpMessage="Enter the name of the VM to be created::"
        )]
        [string]$vmName,
 
        [Parameter(
            Mandatory=$false,
            Position=2,
            HelpMessage="Enter the environment where you want to create the VM::"
        )]
        [ValidateSet("Dedicated","Shared","Cloud")]
        [string]$environment="Shared"

    )
 
    DynamicParam {
        if ($environment -eq "Dedicated") {
            
            #declaring the parameter name for the user name
            $user = 'userName'
            #creating a new ParameterAttribute Object and then setting the attributes of the parameter
            $userAttribute = New-Object System.Management.Automation.ParameterAttribute
            $userAttribute.Position = 3
            $userAttribute.Mandatory = $true
            $userAttribute.HelpMessage = "Only named users can create a VM in this environment. Please enter your name:"
 
            #create an attributecollection object for the attributes we just created
            $attributeCollection = new-object System.Collections.ObjectModel.Collection[System.Attribute]
 
            #adding our defined custom attributes to the collection
            $attributeCollection.Add($userAttribute)
 
            #creating the new dynamic paramater with attributes mentioned in the attribute collection
            $userParam = New-Object System.Management.Automation.RuntimeDefinedParameter($user, [string], $attributeCollection)
 
            #exposing the parameter to the runspace and returning it
            $paramDictionary = New-Object System.Management.Automation.RuntimeDefinedParameterDictionary
            $paramDictionary.Add($user, $userParam)
            return $paramDictionary
          }
    }

   Begin {
       #Checking if the dynamic parameter was created and expected value was provided to it
       if ($PSBoundParameters.userName -and $PSBoundParameters.userName -NotMatch "admin") {
           Write-Error "You do not have enough permission to create a VM in this environment" -ErrorAction Stop
       }
       #Creating an easy parameter name for the Dynamic Parameter so that we can use it easily in the function 
       $userName = $PSBoundParameters.userName
   }
 
   Process {

        # We can create input our custom scripts here to create a VM. For the purpose of checking the script we are just printing the 
        # name to the screen here.     
        if ($environment -ne "Dedicated") {
            Write-Host "You have entered VMname : $vmName Environment: $environment"
        }
        Else{
          Write-Host "You have entered VMname : $vmName Environment: $environment UserID:$userName "
        }
   }
}