# This script creats a scheduled task which will create a snapshot of a VM with the name Test-1
# Get the details of the VM for which snapshot needs to be created

$VM = Get-View -ViewType VirtualMachine -Filter @{“Name” = "Test-1"}

# Create the Action Object with the CreateSnapshot_Task

$ma = New-Object VMware.Vim.MethodAction
$ma.Name = "CreateSnapshot_Task"
$ma.Argument = New-Object VMware.Vim.MethodActionArgument[] (4)

($ma.argument[0] = New-Object VMware.Vim.MethodActionArgument).Value = "$vm.Name scheduled snapshot"
($ma.argument[1] = New-Object VMware.Vim.MethodActionArgument).Value = "Snapshot created"
($ma.argument[2] = New-Object VMware.Vim.MethodActionArgument).Value = $false # Snapshot memory
($ma.argument[3] = New-Object VMware.Vim.MethodActionArgument).Value = $false # quiesce guest file system (requires VMware Tools)

# Setting the values for schedule time

$dts = New-Object VMware.Vim.DailyTaskScheduler
$dts.Hour = 20
$dts.Minute = 0
$dts.Interval = 7

# Creating object for ScheduledTask specification and setting 
# values

$spec = New-Object VMware.Vim.ScheduledTaskSpec
$spec.Name = "Snapshot" + $VM.Name
$spec.Description = "Snapshot" + $VM.Name
$spec.Enabled = $true
$spec.Notification = "sdebnath@vmware.com"
$spec.Action = $ma
$spec.Scheduler = $dts

# Finally creating the task

$si = Get-View ServiceInstance
$stm = Get-View $si.Content.ScheduledTaskManager
$stm.CreateScheduledTask($vm.MoRef,$Spec)
